OC.L10N.register(
    "core",
    {
    "Please select a file." : "파일을 선택하십시오.",
    "File is too big" : "파일이 너무 큼",
    "The selected file is not an image." : "선택한 파일은 사진이 아닙니다.",
    "The selected file cannot be read." : "선택한 파일을 읽을 수 없습니다.",
    "The file was uploaded" : "파일을 업로드했습니다.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과합니다.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과합니다.",
    "The file was only partially uploaded" : "파일이 일부분만 업로드되었습니다.",
    "No file was uploaded" : "업로드한 파일이 없습니다.",
    "Missing a temporary folder" : "임시 폴더가 없습니다.",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능이 파일 업로드를 중단했습니다.",
    "Invalid file provided" : "잘못된 파일 지정됨",
    "No image or file provided" : "사진이나 파일이 없음",
    "Unknown filetype" : "알려지지 않은 파일 형식",
    "An error occurred. Please contact your admin." : "오류가 발생했습니다. 시스템 관리자에게 연락하십시오.",
    "Invalid image" : "잘못된 사진",
    "No temporary profile picture available, try again" : "사용 가능한 프로필 사진이 없습니다. 다시 시도하십시오.",
    "No crop data provided" : "선택된 데이터가 없습니다.",
    "No valid crop data provided" : "올바른 잘라내기 데이터가 지정되지 않음",
    "Crop is not square" : "잘라내는 영역이 사각형이 아님",
    "State token does not match" : "상태 토큰이 일치하지 않습니다.",
    "Invalid app password" : "앱 암호가 잘못됨",
    "Could not complete login" : "로그인을 완료할 수 없음",
    "State token missing" : "상태 토큰 누락",
    "Your login token is invalid or has expired" : "로그인 토큰이 잘못되었거나 만료되었습니다.",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "이 Nextcloud 커뮤니티 릴리즈는 지원하지 않는 버전이며, 푸시 알림은 제한됩니다.",
    "Login" : "로그인",
    "Unsupported email length (>255)" : "지원하지 않는 이메일 길이 (255자 초과)",
    "Password reset is disabled" : "암호 재설정이 비활성화되었습니다.",
    "Could not reset password because the token is expired" : "토큰이 만료되어 암호를 초기화할 수 없습니다.",
    "Could not reset password because the token is invalid" : "토큰이 잘못되었기 때문에 암호를 초기화할 수 없습니다.",
    "Password is too long. Maximum allowed length is 469 characters." : "암호가 너무 깁니다. 암호 최대 길이는 469자입니다.",
    "%s password reset" : "%s 암호 재설정",
    "Password reset" : "암호 재설정",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "아래 단추를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "아래 링크를 눌러서 암호를 재설정할 수 있습니다. 암호 초기화를 요청하지 않으셨다면 이 이메일을 무시하십시오.",
    "Reset your password" : "내 암호 재설정",
    "The given provider is not available" : "주어진 공급자가 사용 가능하지 않습니다.",
    "Task not found" : "작업을 찾을 수 없습니다",
    "Internal error" : "내부 오류",
    "Not found" : "찾을 수 없음",
    "Bad request" : "잘못된 요청",
    "Requested task type does not exist" : "요청한 작업 타입이 존재하지 않음",
    "Necessary language model provider is not available" : "필요한 언어 모델 제공자를 사용할 수 없습니다",
    "No text to image provider is available" : "사용할 수 있는 text to image 제공자가 없습니다.",
    "Image not found" : "이미지를 찾지 못함",
    "No translation provider available" : "이용 가능한 번역 제공자 없음",
    "Could not detect language" : "언어를 감지할 수 없음",
    "Unable to translate" : "번역할 수 없음",
    "Nextcloud Server" : "Nextcloud 서버",
    "Some of your link shares have been removed" : "일부 링크 공유가 제거되었습니다.",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "보안 버그로 인하여 일부 링크 공유를 삭제했습니다. 링크를 눌러서 더 많은 정보를 볼 수 있습니다.",
    "The account limit of this instance is reached." : "이 인스턴스의 계정 한계에 도달했습니다.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "지원 앱에서 가입 키를 입력하여 계정 한도를 늘리세요. 이는 Nextcloud Enterprise의 모든 혜택을 제공하며, 기업에서의 운영에 적극 권장됩니다.",
    "Learn more ↗" : "더 알아보기 ↗",
    "Preparing update" : "업데이트 준비 중",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "수리 단계:",
    "Repair info:" : "수리 정보:",
    "Repair warning:" : "수리 경고:",
    "Repair error:" : "수리 오류:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "당신의 config.php에서 브라우저를 통한 업데이트가 비활성화 되어 있으므로, 명령줄 업데이터를 사용하세요.",
    "Turned on maintenance mode" : "유지 보수 모드 켜짐",
    "Turned off maintenance mode" : "유지 보수 모드 꺼짐",
    "Maintenance mode is kept active" : "유지 보수 모드가 켜져 있음",
    "Updating database schema" : "데이터베이스 스키마 업데이트 중",
    "Updated database" : "데이터베이스 업데이트됨",
    "Update app \"%s\" from App Store" : "앱 스토어에서 \"%s\" 앱 업데이트",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s의 데이터베이스 스키마 업데이트 가능 여부 확인 중(데이터베이스 크기에 따라서 오래 걸릴 수도 있습니다)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\"을(를) %2$s(으)로 업데이트함",
    "Set log level to debug" : "로그 단계를 디버그로 설정",
    "Reset log level" : "로그 단계 초기화",
    "Starting code integrity check" : "코드 무결성 검사 시작 중",
    "Finished code integrity check" : "코드 무결성 검사 완료됨",
    "%s (incompatible)" : "%s(호환 불가)",
    "The following apps have been disabled: %s" : "다음 앱이 비활성화되었습니다: %s",
    "Already up to date" : "최신 상태임",
    "Error occurred while checking server setup" : "서버 설정을 확인하는 중 오류 발생",
    "For more details see the {linkstart}documentation ↗{linkend}." : "더 자세한 사항은 {linkstart}문서 ↗{linkend}를 참조하십시오.",
    "unknown text" : "알 수 없는 텍스트",
    "Hello world!" : "Hello world!",
    "sunny" : "맑음",
    "Hello {name}, the weather is {weather}" : "{name} 님 안녕하세요, 오늘 날씨는 {weather}입니다",
    "Hello {name}" : "{name} 님 안녕하세요",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>검색 결과입니다<script>alert(1)</script></strong>",
    "new" : "새로운 항목",
    "_download %n file_::_download %n files_" : ["파일 %n개 다운로드"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "업데이트 중입니다. 일부 환경에서 이 페이지를 닫을 경우 작업이 중단될 수 있습니다.",
    "Update to {version}" : "{version}(으)로 업데이트",
    "An error occurred." : "오류가 발생했습니다.",
    "Please reload the page." : "페이지를 새로 고치십시오.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "업데이트에 실패했습니다. 더 많은 정보를 보려면 이 문제에 대한 <a href=\"{url}\">포럼 글</a>을 참조하십시오.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "업데이트가 실패했습니다. 이 문제를 <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud 커뮤니티</a>에 보고하여 주십시오.",
    "Continue to {productName}" : "{productName}으로 계속하기",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["업데이트가 성공했습니다. %n초 후 {productName}(으)로 이동합니다."],
    "Applications menu" : "애플리케이션 메뉴",
    "Apps" : "앱",
    "More apps" : "더 많은 앱",
    "_{count} notification_::_{count} notifications_" : ["{count}개의 알림"],
    "No" : "아니요",
    "Yes" : "예",
    "The remote URL must include the user." : "원격 URL에 사용자가 포함되어야 합니다.",
    "Invalid remote URL." : "잘못된 원격 URL입니다.",
    "Failed to add the public link to your Nextcloud" : "Nextcloud에 공개 링크를 추가할 수 없음",
    "Federated user" : "연합 사용자",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "공유 만들기",
    "Direct link copied to clipboard" : "직접 링크가 클립보드에 복사됨",
    "Please copy the link manually:" : "링크를 수동으로 복사해 주세요:",
    "Custom date range" : "맞춤 날짜 범위",
    "Pick start date" : "시작일 선택",
    "Pick end date" : "종료일 선택",
    "Search in date range" : "날짜 범위로 검색",
    "Search in current app" : "현재 앱에서 찾기",
    "Clear search" : "찾기 초기화",
    "Search everywhere" : "모든 곳에서 찾기",
    "Searching …" : "검색 중...",
    "Start typing to search" : "검색어 입력",
    "No matching results" : "일치하는 결과 없음",
    "Today" : "오늘",
    "Last 7 days" : "지난 7일",
    "Last 30 days" : "지난 30일",
    "This year" : "올해",
    "Last year" : "작년",
    "Unified search" : "통합검색",
    "Search apps, files, tags, messages" : "앱 및 파일, 태그, 메시지 검색",
    "Places" : "장소",
    "Date" : "날짜",
    "Search people" : "사람 검색",
    "People" : "사람들",
    "Filter in current view" : "현재 화면을 필터",
    "Results" : "결과들",
    "Load more results" : "더 많은 결과 불러오기",
    "Search in" : "다음에서 검색",
    "Log in" : "로그인",
    "Logging in …" : "로그인 중 …",
    "Log in to {productName}" : "{productName}에 로그인",
    "Wrong login or password." : "로그인 또는 암호가 잘못되었습니다.",
    "This account is disabled" : "이 계정은 비활성화 되었습니다.",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "사용 중인 IP에서 여러 번의 잘못된 로그인 시도를 감지했습니다. 30초 후에 다시 로그인할 수 있습니다.",
    "Account name or email" : "아이디 또는 이메일",
    "Account name" : "계정 아이디",
    "Server side authentication failed!" : "서버 인증 실패!",
    "Please contact your administrator." : "관리자에게 문의하십시오.",
    "Session error" : "세션 오류",
    "It appears your session token has expired, please refresh the page and try again." : "세션 토큰이 만료된 것으로 보입니다. 페이지 새로고침을 하고 다시 시도하세요.",
    "An internal error occurred." : "내부 오류가 발생했습니다.",
    "Please try again or contact your administrator." : "다시 시도하거나 관리자에게 연락하십시오.",
    "Password" : "암호",
    "Log in with a device" : "기기로 로그인",
    "Login or email" : "로그인 또는 이메일",
    "Your account is not setup for passwordless login." : "당신의 계정은 암호 없이 로그인하도록 설정되지 않았습니다.",
    "Your connection is not secure" : "당신의 연결이 안전하지 않습니다.",
    "Passwordless authentication is only available over a secure connection." : "암호 없는 인증은 보안 연결에서만 사용할 수 있습니다.",
    "Browser not supported" : "브라우저를 지원하지 않습니다.",
    "Passwordless authentication is not supported in your browser." : "당신의 브라우저에서 암호 없는 인증을 지원하지 않습니다.",
    "Reset password" : "암호 재설정",
    "Back to login" : "로그인으로 돌아가기",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "계정이 존재한다면, 암호 초기화 메시지가 해당 계정의 이메일 주소로 전송됩니다. 만일 메일을 수신하지 못했다면, 이메일 주소 및 계정 이름을 확인하고 스팸 메일 폴더를 확인하십시오. 또는, 가까운 관리자에게 도움을 요청하십시오.",
    "Couldn't send reset email. Please contact your administrator." : "재설정 메일을 보낼 수 없습니다. 관리자에게 문의하십시오.",
    "Password cannot be changed. Please contact your administrator." : "암호를 변경할 수 없습니다. 관리자에게 문의하십시오.",
    "New password" : "새 암호",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "내 파일이 암호화되어 있습니다. 암호를 초기화하면 데이터를 복구할 수 없습니다.<br />무엇을 해야 할 지 잘 모르겠으면 시스템 관리자에게 연락하십시오.<br />그래도 계속 진행하시겠습니까?",
    "I know what I'm doing" : "지금 하려는 것을 알고 있습니다",
    "Resetting password" : "암호 재설정",
    "Schedule work & meetings, synced with all your devices." : "업우와 회의 일정을 짜고, 당신의 모든 기기와 동기화하세요.",
    "Keep your colleagues and friends in one place without leaking their private info." : "개인정보 누출 없이 동료와 친구들을 한 곳으로 모아두세요.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "파일 연락처 달력과 통합되는 간단한 이메일 앱",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "채팅, 영상 통화, 화면 공유, 온라인 미팅과 웹 회의 – 여러분의 브라우저와 모바일 앱에서.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online에 기반한 협업 문서, 스프레드시트와 프레젠테이션",
    "Distraction free note taking app." : "방해 없는 무료 메모 작성 앱.",
    "Recommended apps" : "추천되는 앱",
    "Loading apps …" : "앱 로딩중 ...",
    "Could not fetch list of apps from the App Store." : "앱스토어로부터 앱 목록을 가져올 수 없음",
    "App download or installation failed" : "앱 다운로드 또는 설치에 실패함",
    "Cannot install this app because it is not compatible" : "호환되지 않아 앱을 설치할 수 없습니다.",
    "Cannot install this app" : "앱을 설치할 수 없음",
    "Skip" : "건너뛰기",
    "Installing apps …" : "앱 설치중...",
    "Install recommended apps" : "추천 앱 설치",
    "Avatar of {displayName}" : "{displayName}의 아바타",
    "Settings menu" : "설정 메뉴",
    "Loading your contacts …" : "연락처 불러오는 중 …",
    "Looking for {term} …" : "{term} 검색 중 …",
    "Search contacts" : "연락처 검색",
    "Reset search" : "검색 초기화",
    "Search contacts …" : "연락처 검색…",
    "Could not load your contacts" : "연락처를 불러올 수 없음",
    "No contacts found" : "연락처를 찾을 수 없음",
    "Show all contacts" : "모든 연락처 보기",
    "Install the Contacts app" : "Contacts 앱 설치",
    "Search" : "검색",
    "No results for {query}" : "{query}에 대한 결과가 없음",
    "Press Enter to start searching" : "검색을 시작하려면 엔터를 누르세요.",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["{minSearchLength}개 이상의 글자를 입력해 검색해 주세요."],
    "An error occurred while searching for {type}" : "{type} 탐색중 오류 발생",
    "Search starts once you start typing and results may be reached with the arrow keys" : "입력을 시작하면 검색이 시작되며, 방향키를 통해 결과로 이동할 수 있습니다.",
    "Search for {name} only" : "{name}(으)로만 검색",
    "Loading more results …" : "더 많은 결과 불러오는 중...",
    "Forgot password?" : "암호를 잊으셨습니까?",
    "Back to login form" : "로그인으로 돌아가기",
    "Back" : "뒤로",
    "Login form is disabled." : "로그인 양식이 비활성화 되었습니다.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud 로그인 양식이 비활성화 되었습니다. 이용 가능한 다른 방법으로 로그인 하거나, 관리자에게 문의하십시오.",
    "More actions" : "더 많은 동작",
    "Password is too weak" : "너무 약한 암호",
    "Password is weak" : "약한 암호",
    "Password is average" : "보통 암호",
    "Password is strong" : "강한 암호",
    "Password is very strong" : "매우 강한 암호",
    "Password is extremely strong" : "극도로 강한 암호",
    "Unknown password strength" : "알 수 없는 암호 강도",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "<code>.htaccess</code>파일이 작동하지 않아 당신의 데이터 디렉토리와 파일이 인터넷에 노출될 수도 있습니다.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "서버를 적절히 구성하기 위한 정보는  {linkStart}문서를 참조하세요{linkEnd}",
    "Autoconfig file detected" : "자동구성 파일 감지됨",
    "The setup form below is pre-filled with the values from the config file." : "아래 설정 입력란은 설정파일의 값으로 미리 입력됩니다.",
    "Security warning" : "보안 경고",
    "Create administration account" : "관리자 계정 생성",
    "Administration account name" : "관리자 계정 이름",
    "Administration account password" : "관리자 계정 암호",
    "Storage & database" : "저장소 및 데이터베이스",
    "Data folder" : "데이터 폴더",
    "Database configuration" : "데이터베이스 구성",
    "Only {firstAndOnlyDatabase} is available." : "오직 {firstAndOnlyDatabase}만 가능합니다.",
    "Install and activate additional PHP modules to choose other database types." : "다른 데이터베이스 종류를 사용하려면 추가 PHP 모듈을 설치 및 활성화하십시오.",
    "For more details check out the documentation." : "자세한 정보를 보려면 문서를 참고하십시오.",
    "Performance warning" : "성능 경고",
    "You chose SQLite as database." : "데이터베이스로 SQLite를 선택하셨습니다.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite는 최소 및 개발 목적의 인스턴스에만 사용하는 것을 추천합니다. 실제 업무에 사용하려면 다른 데이터베이스 백엔드를 사용하십시오.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "만약 파일 동기화 클라이언트를 사용하려고 한다면 SQLite를 사용하지 않는 것이 좋습니다.",
    "Database user" : "데이터베이스 사용자",
    "Database password" : "데이터베이스 암호",
    "Database name" : "데이터베이스 이름",
    "Database tablespace" : "데이터베이스 테이블 공간",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "호스트 이름과 함께 포트 번호를 지정하십시오(예: localhost:5432)",
    "Database host" : "데이터베이스 호스트",
    "localhost" : "로컬호스트",
    "Installing …" : "설치중…",
    "Install" : "설치",
    "Need help?" : "도움이 필요한가요?",
    "See the documentation" : "문서 보기",
    "{name} version {version} and above" : "{name}의 {version} 버전 이상",
    "This browser is not supported" : "이 브라우저는 지원되지 않습니다.",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "이 브라우저는 지원되지 않습니다. 새로운 버전 및 지원되는 브라우저로 업그레이드 하세요.",
    "Continue with this unsupported browser" : "지원되지 않는 브라우저로 계속 사용하기",
    "Supported versions" : "지원되는 버전",
    "Search {types} …" : "{types} 검색 ...",
    "Choose {file}" : "{file} 선택",
    "Choose" : "선택",
    "Copy to {target}" : "{target}에 복사",
    "Copy" : "복사",
    "Move to {target}" : "{target}에 이동",
    "Move" : "이동",
    "OK" : "확인",
    "read-only" : "읽기 전용",
    "_{count} file conflict_::_{count} file conflicts_" : ["파일 {count}개 충돌"],
    "One file conflict" : "파일 1개 충돌",
    "New Files" : "새 파일",
    "Already existing files" : "기존 파일",
    "Which files do you want to keep?" : "어느 파일을 유지하시겠습니까?",
    "If you select both versions, the copied file will have a number added to its name." : "두 버전을 모두 선택하면 복사된 파일 이름에 번호가 추가됩니다.",
    "Cancel" : "취소",
    "Continue" : "계속",
    "(all selected)" : "(모두 선택됨)",
    "({count} selected)" : "({count}개 선택됨)",
    "Error loading file exists template" : "파일 존재함 템플릿을 불러오는 중 오류 발생",
    "Saving …" : "저장 중 …",
    "seconds ago" : "몇 초 전",
    "Connection to server lost" : "서버 연결이 끊어짐",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["페이지 불러오기 오류, %n초 후 새로 고침"],
    "Add to a project" : "프로젝트에 추가",
    "Show details" : "세부 정보",
    "Hide details" : "자세한 정보 숨기기",
    "Rename project" : "프로젝트 이름 변경",
    "Failed to rename the project" : "프로젝트 이름 변경 실패",
    "Failed to create a project" : "프로젝트 생성 실패",
    "Failed to add the item to the project" : "프로젝트에 아이템 추가 실패",
    "Connect items to a project to make them easier to find" : "폴더 또는 파일을 찾기 쉽게 프로젝트에 연결하세요.",
    "Type to search for existing projects" : "이미 존재하는 프로젝트를 찾기 위해 입력하세요.",
    "New in" : "새로운 것",
    "View changelog" : "변경 기록 확인",
    "No action available" : "사용할 수 있는 동작 없음",
    "Error fetching contact actions" : "연락처 동작을 가져오는 중 오류 발생",
    "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" 대화 상자 닫기",
    "Email length is at max (255)" : "이메일 길이가 최대입니다 (255)",
    "Non-existing tag #{tag}" : "존재하지 않는 태그 #{tag}",
    "Restricted" : "제한됨",
    "Invisible" : "숨겨짐",
    "Delete" : "삭제",
    "Rename" : "이름 바꾸기",
    "Collaborative tags" : "협동 태그",
    "No tags found" : "태그를 찾을 수 없음",
    "Clipboard not available, please copy manually" : "클립보드를 사용할 수 없으므로, 수동으로 복사해 주세요.",
    "Personal" : "개인",
    "Accounts" : "계정",
    "Admin" : "관리자",
    "Help" : "도움말",
    "Access forbidden" : "접근 금지됨",
    "Page not found" : "페이지를 찾을 수 없음",
    "The page could not be found on the server or you may not be allowed to view it." : "페이지를 서버에서 찾을 수 없거나, 페이지를 보도록 허가되지 않았습니다.",
    "Back to %s" : "%s(으)로 돌아가기",
    "Too many requests" : "요청이 너무 많음",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "이 네트워크에 너무 요청이 많습니다. 나중에 다시 시도하십시오. 이것이 오류일 경우 관리자에게 문의하십시오.",
    "Error" : "오류",
    "Internal Server Error" : "내부 서버 오류",
    "The server was unable to complete your request." : "서버에서 요청을 처리할 수 없습니다.",
    "If this happens again, please send the technical details below to the server administrator." : "만약 이 오류가 다시 발생하면 서버 관리자에게 다음 기술 정보를 알려 주십시오.",
    "More details can be found in the server log." : "서버 로그에서 자세한 정보를 찾을 수 있습니다.",
    "For more details see the documentation ↗." : "좀 더 자세한 사항은 문서를 참고하세요↗.",
    "Technical details" : "기술 정보",
    "Remote Address: %s" : "원격 주소: %s",
    "Request ID: %s" : "요청 ID: %s",
    "Type: %s" : "종류: %s",
    "Code: %s" : "코드: %s",
    "Message: %s" : "메시지: %s",
    "File: %s" : "파일: %s",
    "Line: %s" : "줄: %s",
    "Trace" : "추적",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloud를 다시 설치하려고 하는 것 같습니다. 그러나 현재 설정 디렉터리에 CAN_INSTALL 파일이 없는 것 같습니다. 계속 진행하려면 설정 폴더에 CAN_INSTALL 폴더를 만드십시오.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "설정 폴더에서 CAN_INSTALL 파일을 삭제할 수 없습니다. 직접 삭제하십시오.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "이 프로그램이 올바르게 작동하려면 자바스크립트가 필요합니다. {linkstart}자바스크립트를 활성화{linkend}한 다음 페이지를 새로 고치십시오.",
    "Skip to main content" : "주 내용으로 이동",
    "Skip to navigation of app" : "앱 탐색으로 이동",
    "Go to %s" : "%s로 이동",
    "Get your own free account" : "무료 계정 등록",
    "Connect to your account" : "내 계정에 연결",
    "Please log in before granting %1$s access to your %2$s account." : "%1$s에서 내 %2$s 계정에 접근하는 것을 허용하려면 로그인해야 합니다.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "새 기기나 앱을 설정하지 않고 있다면, 누군가 당신을 속여 데이터 접근 권한을 얻으려 하는 것일 수도 있습니다. 이러한 경우 절대 허가하지 말고 시스템 관리자에게 문의하십시오.",
    "App password" : "앱 암호",
    "Grant access" : "접근 허용",
    "Alternative log in using app password" : "앱 암호로 대체 로그인",
    "Account access" : "계정 접근",
    "Currently logged in as %1$s (%2$s)." : "현재 %1$s(%2$s)(으)로 로그인됨.",
    "You are about to grant %1$s access to your %2$s account." : "%1$s에서 내 %2$s 계정에 접근하는 것을 허용하려고 합니다.",
    "Account connected" : "계정 연결됨",
    "Your client should now be connected!" : "이제 클라이언트가 연결되야 합니다.",
    "You can close this window." : "윈도우를 닫으셔도 됩니다.",
    "Previous" : "이전",
    "This share is password-protected" : "이 공유는 암호로 보호되어 있습니다.",
    "The password is wrong or expired. Please try again or request a new one." : "암호가 틀렸거나 만료되었습니다. 다시 시도하거나 새로운 암호를 요청하십시오.",
    "Please type in your email address to request a temporary password" : "임시 암호를 받기 위해 이메일 주소를 입력하십시오.",
    "Email address" : "이메일 주소",
    "Password sent!" : "암호가 발송되었습니다!",
    "You are not authorized to request a password for this share" : "이 공유의 암호를 요청할 권한이 없습니다.",
    "Two-factor authentication" : "2단계 인증",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "현재 계정에 향상된 보안이 켜져 있습니다. 2단계 인증 방식을 선택하십시오:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "2단계 인증 방식을 불러올 수 없습니다. 관리자에게 문의하십시오.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "2단계 인증이 필수로 설정되어 있지만 현재 계정에 설정되어 있지 않습니다. 관리자에게 도움을 요청하십시오.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "2단계 인증이 필수로 설정되어 있지만 현재 계정에 설정되어 있지 않습니다. 계속 진행하여 2단계 인증을 설정하십시오.",
    "Set up two-factor authentication" : "2단계 인증 설정",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "2단계 인증이 필수로 설정되어 있지만 현재 계정에 설정되어 있지 않습니다. 백업 코드를 사용하여 로그인하거나 관리자에게 도움을 요청하십시오.",
    "Use backup code" : "백업 코드 사용",
    "Cancel login" : "로그인 취소",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "당신의 계정에 향상된 보안이 강제됩니다. 설정하려는 제공자를 선택하십시오:",
    "Error while validating your second factor" : "2단계 인증을 검증하는 중 오류 발생",
    "Access through untrusted domain" : "신뢰하지 않는 도메인으로 접근",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "시스템 관리자에게 연락하십시오. 만약 시스템 관리자라면 config/config.php의 \"trusted_domains\" 설정을 config.sample.php를 참조하여 편집하십시오.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "설정하는 방법에 대한 정보는 %1$s문서%2$s에서 찾을 수 있습니다.",
    "App update required" : "앱 업데이트 필요",
    "%1$s will be updated to version %2$s" : "%1$s을(를) 버전 %2$s(으)로 업데이트합니다.",
    "The following apps will be updated:" : "업데이트 예정인 앱:",
    "These incompatible apps will be disabled:" : "다음 호환되지 않는 앱이 비활성화됩니다:",
    "The theme %s has been disabled." : "%s 테마가 비활성화되었습니다.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "계속하기 전에 데이터베이스, 설정 폴더, 데이터 폴더가 백업되어 있는지 확인하십시오.",
    "Start update" : "업데이트 시작",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "큰 파일을 설치하는 경우 시간이 초과될 수 있으므로, 설치 디렉터리에서 다음 명령을 실행하셔도 됩니다:",
    "Detailed logs" : "자세한 로그",
    "Update needed" : "업데이트 필요",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "50개 이상의 계정이 있는 큰 인스턴스이므로 명령줄 업데이터를 사용하시기 바랍니다.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "도움말을 보려면 <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">문서</a>를 참조하십시오.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "웹 UI를 통한 업데이트 시 요청 시간이 초과되어 데이터가 손실될 수 있는 위험성을 알고 있으며, 내 데이터를 백업해 두었고 실패한 경우 복원할 수 있는 방법을 알고 있습니다.",
    "Upgrade via web on my own risk" : "그래도 웹으로 업데이트하기",
    "Maintenance mode" : "유지 보수 모드",
    "This %s instance is currently in maintenance mode, which may take a while." : "이 %s 인스턴스는 현재 점검 모드입니다. 시간이 걸릴 수도 있습니다.",
    "This page will refresh itself when the instance is available again." : "인스턴스를 다시 사용할 수 있을 때 페이지를 자동으로 새로 고칩니다.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "이 메시지가 계속 표시되거나 예상하지 못하였을 때 표시된다면 시스템 관리자에게 연락하십시오.",
    "Currently open" : "현재 열려있음",
    "Login with username or email" : "아이디 또는 이메일로 로그인",
    "Login with username" : "아이디로 로그인",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "당신의 브라우저와 모바일 앱 속의  채팅, 영상 통화, 화면 공유, 온라인 미팅 그리고 웹 회의",
    "You have not added any info yet" : "아직 아무 정보도 추가하지 않았습니다.",
    "{user} has not added any info yet" : "{user}님이 아직 아무 정보도 추가하지 않음",
    "Error opening the user status modal, try hard refreshing the page" : "사용자 상태 모달을 불러오는 데 실패했습니다, 페이지를 완전히 새로고침 해 보십시오.",
    "Edit Profile" : "프로필 수정",
    "The headline and about sections will show up here" : "표제와 기타 정보가 이곳에 나타납니다.",
    "Error loading message template: {error}" : "메시지 템플릿을 불러오는 중 오류 발생: {error}",
    "Very weak password" : "매우 약한 암호",
    "Weak password" : "약한 암호",
    "So-so password" : "그저 그런 암호",
    "Good password" : "좋은 암호",
    "Strong password" : "강력한 암호",
    "Profile not found" : "프로필 찾을 수 없음",
    "The profile does not exist." : "프로필이 존재하지 않습니다.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess 파일이 처리되지 않아서 데이터 디렉터리와 파일을 인터넷에서 접근할 수도 있습니다.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "서버를 올바르게 설정하는 방법에 대해서 더 알아보려면 <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">문서</a>를 참조하십시오.",
    "<strong>Create an admin account</strong>" : "<strong>관리자 계정 만들기</strong>",
    "New admin account name" : "새 관리자 계정 이름",
    "New admin password" : "새 관리자 비밀번호",
    "Show password" : "암호 표시",
    "Toggle password visibility" : "암호 보이기/숨기기",
    "Configure the database" : "데이터베이스 설정",
    "Only %s is available." : "%s만 사용할 수 있습니다.",
    "Database account" : "데이터베이스 계정"
},
"nplurals=1; plural=0;");
